@@ -22,8 +22,10 @@ from _pygalmesh import (
     Union,
 )
 
+from . import _cli
 from .__about__ import __version__
 from .main import (
+    generate_2d,
     generate_from_array,
     generate_from_inr,
     generate_mesh,
@@ -37,6 +39,8 @@ from .main import (
 __all__ = [
     "__version__",
     #
+    "_cli",
+    #
     "DomainBase",
     "SizingFieldBase",
     "Translate",
@@ -59,6 +63,7 @@ __all__ = [
     "RingExtrude",
     #
     "generate_mesh",
+    "generate_2d",
     "generate_periodic_mesh",
     "generate_surface_mesh",
     "generate_volume_mesh_from_surface_mesh",
